@@ -1161,6 +1161,8 @@ class PlominoReplicationManager(Persistent):
         # export attached files
         for f in doc.getFilenames():
             attached_file = doc.getfile(f)
+            if not attached_file:
+                continue
             fnode = xmldoc.createElement('attachment')
             fnode.setAttribute('id', f)
             fnode.setAttribute('contenttype', getattr(attached_file, 'content_type',''))
@@ -1185,28 +1187,31 @@ class PlominoReplicationManager(Persistent):
         """
         logger.info("Start documents import")
         self.setStatus("Importing documents (0%)")
-        xml_files = []
         txn = transaction.get()
-        if REQUEST:
-            sourcetype = REQUEST.get('sourcetype', sourcetype)
-        if sourcetype == 'sourceFile':
+        xml_files = []
+        if xmlstring:
+            xmlstring_arg = True
+            xml_files = [xmlstring]
+        else:
+            xmlstring_arg = False
             if REQUEST:
-                xml_files = [REQUEST.get("file")]
-            else:
-                xml_files = [xmlstring]
-        elif sourcetype == 'folder':
-            if REQUEST:
-                from_folder=REQUEST.get("from_folder")
-            xml_files = glob.glob(os.path.join(from_folder, '*.xml'))
+                sourcetype = REQUEST.get('sourcetype', sourcetype)
+            if sourcetype == 'sourceFile':
+                if REQUEST:
+                    xml_files = [REQUEST.get("file")]
+                elif file:
+                    xml_files = [file]
+            elif sourcetype == 'folder':
+                if REQUEST:
+                    from_folder=REQUEST.get("from_folder")
+                xml_files = glob.glob(os.path.join(from_folder, '*.xml'))
 
         files_counter = 0
         errors = 0
         imports = 0
 
         for xml_file in xml_files:
-            if isinstance(xml_file, basestring):
-                xmlstring = xml_file
-            else:
+            if not xmlstring_arg:
                 if hasattr(xml_file, 'read'):
                     xmlstring = xml_file.read()
                 else:
@@ -1251,12 +1256,9 @@ class PlominoReplicationManager(Persistent):
 
     security.declareProtected(CREATE_PERMISSION, 'importDocumentFromXML')
     def importDocumentFromXML(self, node):
-        docid = node.getAttribute('id')
+        docid = node.getAttribute('id').encode('ascii')
         lastmodified = DateTime(node.getAttribute('lastmodified'))
-        pt = getToolByName(self, 'portal_types')
-        pt.constructContent('PlominoDocument', self.documents, docid)
-        #self.invokeFactory(type_name='PlominoDocument', id=docid)
-        doc = self.documents.get(docid)
+        doc = self.createDocument(docid)
 
         # restore items
         itemnode = node.getElementsByTagName("params")[0]
